@@ -17,6 +17,8 @@ fn test() {
                         <div>"1"</div>
                         <div>"2"</div>
                         <div>"3"</div>
+                        <div {"some-attribute-from-rust-block"}/>
+                        <div>{%= "<uwu>" %}</div>
                     </>
                 </body>
             </html>
@@ -33,10 +35,12 @@ fn test() {
                     <div>1</div>
                     <div>2</div>
                     <div>3</div>
+                    <div some-attribute-from-rust-block></div>
+                    <div>&lt;uwu&gt;</div>
                 </body>
             </html>
         "#
-        .split("\n")
+        .split('\n')
         .map(|line| line.trim())
         .collect::<Vec<&str>>()
         .join("")
